@@ -16,7 +16,7 @@
 //!
 //! ### Type support
 //! - **Primitive support:** `+`, `-`, `*` and `/` operations are supported.
-//! - **Extended support:** All operations from [std::ops] are supproted.
+//! - **Extended support:** All operations from [std::ops] are supported.
 //! - **Near-full support:** Almost* all native operations (operations implemented by the library which defines the type) are supported.
 //!
 //! Please note these just specify a minimum set of operations, full details of other specific supported operations are given below.
@@ -49,3 +49,6 @@
 //! - [Automatic Differentation in Rust](https://github.com/JonathanWoollett-Light/autodiff-book)
 //! - [automatic-differentiation-worked-examples](http://h2.jaguarpaw.co.uk/posts/automatic-differentiation-worked-examples/)
 pub use rust_ad_macros::*;
+
+#[cfg(test)]
+mod tests;
